@@ -19,6 +19,7 @@ import json
 import shutil
 from shutil import copy2
 import ruamel.yaml as yaml
+import numpy as np
 
 def make_parent_dir(filename):
     parent_dir = os.path.dirname(filename)
@@ -35,6 +36,9 @@ def is_empty(path):
 
 
 def load(filename):
+    # adding the symbolic link reading
+    if os.path.islink(filename): 
+        filename = os.readlink(filename)
     if filename.endswith('.pkl'):
         with open(filename, 'rb') as f:
             loaded = pickle.load(f)
@@ -44,7 +48,7 @@ def load(filename):
     elif filename.endswith('.yml') or filename.endswith('.yaml'): 
         with open(filename, 'r') as f:
             loaded = yaml.safe_load(f)
-    elif filename.endswith('.txt') or filename.endswith('.sh') or filename.endswith('.bash'): 
+    elif filename.endswith('.txt') or filename.endswith('.md') or filename.endswith('.sh') or filename.endswith('.bash') or filename.endswith('.log'): 
         with open(filename, 'r') as f:
             loaded = f.read()
     else:
@@ -68,7 +72,7 @@ def dump(content, filename):
     elif filename.endswith('.yml') or filename.endswith('.yaml'): 
         with open(filename, 'w') as f:
             yaml.safe_dump(content, f)
-    elif filename.endswith('.txt') or filename.endswith('.sh') or filename.endswith('.bash'): 
+    elif filename.endswith('.txt') or filename.endswith('.md') or filename.endswith('.sh') or filename.endswith('.bash') or filename.endswith('.log'): 
         with open(filename, 'w') as f:
             f.write(content)
     else:
